.. currentmodule:: sardana.tango.pool.PseudoCounter

:mod:`~sardana.tango.pool.PseudoCounter`
=========================================

.. automodule:: sardana.tango.pool.PseudoCounter

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PseudoCounter`
    * :class:`PseudoCounterClass`

PseudoCounter
-------------

.. inheritance-diagram:: PseudoCounter
    :parts: 1
    
.. autoclass:: PseudoCounter
    :show-inheritance:
    :members:
    :undoc-members:

PseudoCounterClass
-------------------

.. inheritance-diagram:: PseudoCounterClass
    :parts: 1
    
.. autoclass:: PseudoCounterClass
    :show-inheritance:
    :members:
    :undoc-members:

